🔸RISAT-1A — PolSARtools 0.8 documentation

Skip to main content
`Ctrl`+`K`

# 🔸RISAT-1A

## Level 1.1 (`risat_l11`)

The risat_l11 function extracts Sxy/C2 matrix elements from the given RISAT product folder and saves them into a directory.

polsartools.risat_l11(prod_dir, matrixType='C2', azlks=10, rglks=7, outType='tif')

  Extracts the Sxy/C2 matrix elements from a RISAT-1A compact-pol SLC data

  ### Example:

      >>> risat_l11("path_to_folder", matrixType='C2', azlks=10, rglks=7, outType='tif')
      This will extract the C2 from compact-pol RISAT-1A SLC data and save them as geotiff files.
      Additionally, it will also extract the incidence angle map and save it as a geotiff file.

  ### Parameters:

  inFilestr

    The path to the RISAT-1A SLCfolder containing the data and metadata.

  matrixTypestr, optional (default = ‘C2’)

    Type of matrix to extract. Valid options ‘Sxy’,’C2’.

  azlksint, optional (default=10)

    The number of azimuth looks for multi-looking.

  rglksint, optional (default=7)

    The number of range looks for multi-looking.

  ### Returns:

  None

    The function does not return any value. Instead, it creates a folder named Sxy/C2 (if not already present) and saves the geotiff/binary files: